==> eyflutter_uikit-0.0.8%2B8.tar.gz: lib/uikit/bars/opacity_app_bar.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';

mixin OpacityAppBarOption {
  void updateOpacity(double opacity);

  double getAppBarHeight();
}

typedef OpacityAppBarCall(OpacityAppBarOption option);

class OpacityAppBar extends StatefulWidget {
  /// app bar listener
  final OpacityAppBarCall? call;

  /// 标题
  final String? title;

  /// 标题颜色
  final Color titleColor;

  /// app bar 右边按钮
  final List<Widget>? actions;

  /// 返回组件
  final Widget? backIcon;

  /// 返回事件
  final VoidCallback? backClick;

  const OpacityAppBar({
    Key? key,
    this.call,
    this.title,
    this.titleColor = const Color(0xff333333),
    this.actions,
    this.backIcon,
    this.backClick,
  }) : super(key: key);

  @override
  _OpacityAppBarState createState() => _OpacityAppBarState();
}

class _OpacityAppBarState extends State<OpacityAppBar> with OpacityAppBarOption {
  double stateHeight = 0;
  double appBarOpacity = 0;

  @override
  void initState() {
    super.initState();
    stateHeight = MediaQueryData
        .fromWindow(window)
        .padding
        .top;
    if (widget.call != null) {
      widget.call!(this);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Opacity(
          opacity: appBarOpacity,
          child: Container(
            height: kToolbarHeight + stateHeight,
            child: AppBar(
              title: Text(
                widget.title ?? "",
                style: TextStyle(fontSize: 18, color: widget.titleColor),
              ),
              centerTitle: true,
              elevation: 0,
              shadowColor: Colors.transparent,
              backgroundColor: Colors.white,
              actions: widget.actions ?? [],
            ),
          ),
        ),
        Positioned(
          child: GestureDetector(
            child: widget.backIcon ?? Container(),
            onTap: () {
              if (widget.backClick != null) {
                widget.backClick!();
              }
            },
          ),
          bottom: 12,
          left: 10,
        )
      ],
    );
  }

  @override
  void updateOpacity(double opacity) {
    setState(() {
      appBarOpacity = opacity;
    });
  }

  @override
  double getAppBarHeight() {
    return kToolbarHeight + stateHeight;
  }
}

==> eyflutter_uikit-0.1.4%2B8.tar.gz: lib/uikit/bars/opacity_app_bar.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';

mixin OpacityAppBarOption {
  void updateOpacity(double opacity);

  double getAppBarHeight();
}

typedef OpacityAppBarCall(OpacityAppBarOption option);

class OpacityAppBar extends StatefulWidget {
  /// app bar listener
  final OpacityAppBarCall? call;

  /// 标题
  final String? title;

  /// 标题颜色
  final Color titleColor;

  /// app bar 右边按钮
  final List<Widget>? actions;

  /// 返回组件
  final Widget? backIcon;

  /// 返回事件
  final VoidCallback? backClick;

  final Color? backgroundColor;

  final bool enableActionBarGradient;

  const OpacityAppBar({
    Key? key,
    this.call,
    this.title,
    this.titleColor = const Color(0xff333333),
    this.actions,
    this.backIcon,
    this.backClick,
    this.backgroundColor,
    this.enableActionBarGradient = false,
  }) : super(key: key);

  @override
  _OpacityAppBarState createState() => _OpacityAppBarState();
}

class _OpacityAppBarState extends State<OpacityAppBar> with OpacityAppBarOption {
  double stateHeight = 0;
  double appBarOpacity = 0;

  @override
  void initState() {
    super.initState();
    stateHeight = MediaQueryData.fromWindow(window).padding.top;
    if (widget.call != null) {
      widget.call!(this);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Opacity(
          opacity: widget.enableActionBarGradient ? appBarOpacity : 0,
          child: Container(
            height: kToolbarHeight + stateHeight,
            child: AppBar(
              title: Text(
                widget.title ?? "",
                style: TextStyle(fontSize: 18, color: widget.titleColor),
              ),
              centerTitle: true,
              elevation: 0,
              shadowColor: Colors.transparent,
              backgroundColor: Colors.red,
              actions: widget.actions ?? [],
            ),
          ),
        ),
        Positioned(
          child: GestureDetector(
            child: widget.backIcon ?? Container(),
            onTap: () {
              if (widget.backClick != null) {
                widget.backClick!();
              }
            },
          ),
          bottom: 12,
          left: 10,
        )
      ],
    );
  }

  @override
  void updateOpacity(double opacity) {
    if (mounted) {
      setState(() {
        appBarOpacity = opacity;
      });
    }
  }

  @override
  double getAppBarHeight() {
    return kToolbarHeight + stateHeight;
  }
}
